==> vipps_recurring_payments-8.x-1.0-beta1.tar.gz: vipps_recurring_payments/src/Form/VippsAgreementsRevisionDeleteForm.php <==
<?php

namespace Drupal\vipps_recurring_payments\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a form for deleting a Vipps agreements revision.
 *
 * @ingroup vipps_recurring_payments
 */
class VippsAgreementsRevisionDeleteForm extends ConfirmFormBase {

  /**
   * The Vipps agreements revision.
   *
   * @var \Drupal\vipps_recurring_payments\Entity\VippsAgreementsInterface
   */
  protected $revision;

  /**
   * The Vipps agreements storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $vippsAgreementsStorage;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->vippsAgreementsStorage = $container->get('entity_type.manager')->getStorage('vipps_agreements');
    $instance->connection = $container->get('database');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'vipps_agreements_revision_delete_confirm';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the revision from %revision-date?', [
      '%revision-date' => format_date($this->revision->getRevisionCreationTime()),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('entity.vipps_agreements.version_history', ['vipps_agreements' => $this->revision->id()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $vipps_agreements_revision = NULL) {
    $this->revision = $this->VippsAgreementsStorage->loadRevision($vipps_agreements_revision);
    $form = parent::buildForm($form, $form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->VippsAgreementsStorage->deleteRevision($this->revision->getRevisionId());

    $this->logger('content')->notice('Vipps agreements: deleted %title revision %revision.', ['%title' => $this->revision->label(), '%revision' => $this->revision->getRevisionId()]);
    $this->messenger()->addMessage(t('Revision from %revision-date of Vipps agreements %title has been deleted.', ['%revision-date' => format_date($this->revision->getRevisionCreationTime()), '%title' => $this->revision->label()]));
    $form_state->setRedirect(
      'entity.vipps_agreements.canonical',
       ['vipps_agreements' => $this->revision->id()]
    );
    if ($this->connection->query('SELECT COUNT(DISTINCT vid) FROM {vipps_agreements_field_revision} WHERE id = :id', [':id' => $this->revision->id()])->fetchField() > 1) {
      $form_state->setRedirect(
        'entity.vipps_agreements.version_history',
         ['vipps_agreements' => $this->revision->id()]
      );
    }
  }

}

==> vipps_recurring_payments-8.x-2.1-beta1.tar.gz: vipps_recurring_payments/src/Form/VippsAgreementsRevisionDeleteForm.php <==
<?php

namespace Drupal\vipps_recurring_payments\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a form for deleting a Vipps agreements revision.
 *
 * @ingroup vipps_recurring_payments
 */
class VippsAgreementsRevisionDeleteForm extends ConfirmFormBase {

  /**
   * The Vipps agreements revision.
   *
   * @var \Drupal\vipps_recurring_payments\Entity\VippsAgreementsInterface
   */
  protected $revision;

  /**
   * The Vipps agreements storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $vippsAgreementsStorage;

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $connection;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->vippsAgreementsStorage = $container->get('entity_type.manager')->getStorage('vipps_agreements');
    $instance->connection = $container->get('database');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'vipps_agreements_revision_delete_confirm';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the revision from %revision-date?', [
      '%revision-date' => \Drupal::service('date.formatter')->format($this->revision->getRevisionCreationTime()),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('entity.vipps_agreements.version_history', ['vipps_agreements' => $this->revision->id()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $vipps_agreements_revision = NULL) {
    $this->revision = $this->VippsAgreementsStorage->loadRevision($vipps_agreements_revision);
    $form = parent::buildForm($form, $form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->VippsAgreementsStorage->deleteRevision($this->revision->getRevisionId());

    $this->logger('content')->notice('Vipps agreements: deleted %title revision %revision.', ['%title' => $this->revision->label(), '%revision' => $this->revision->getRevisionId()]);
    $this->messenger()->addMessage($this->t('Revision from %revision-date of Vipps agreements %title has been deleted.', ['%revision-date' => \Drupal::service('date.formatter')->format($this->revision->getRevisionCreationTime()), '%title' => $this->revision->label()]));
    $form_state->setRedirect(
      'entity.vipps_agreements.canonical',
       ['vipps_agreements' => $this->revision->id()]
    );
    if ($this->connection->query('SELECT COUNT(DISTINCT vid) FROM {vipps_agreements_field_revision} WHERE id = :id', [':id' => $this->revision->id()])->fetchField() > 1) {
      $form_state->setRedirect(
        'entity.vipps_agreements.version_history',
         ['vipps_agreements' => $this->revision->id()]
      );
    }
  }

}
